@@ -168,8 +168,12 @@ async def _append_line(filename, line):
     append_file.write("\n" + line)
     append_file.close()
 
-async def watch(stream, prefix=''):
+async def watch(stream, cmd):
+    x = True
     async for line in stream:
+        if x:
+            log.info(cmd)
+            x = False
         print(line.decode().strip())
 
 @asyncio.coroutine
@@ -297,7 +301,7 @@ class Task(object):
         os.chdir(self.dir)
 
         self.proc = await asyncio.create_subprocess_shell( cmd, stdout=asyncio.subprocess.PIPE, stderr=asyncio.subprocess.PIPE)
-        await asyncio.gather(watch(self.proc.stdout, '[stdout]'), watch(self.proc.stderr, '[stderr]'))
+        await asyncio.gather(watch(self.proc.stdout, self.cmd), watch(self.proc.stderr, '[stderr]'))
 
         await self.proc.wait()
         await load_env(rando)
@@ -400,7 +404,6 @@ class SequentialTaskList(TaskList):
 #                        pprint(vars(run_task))
                     if isinstance(run_task, Task):
                         run_task.cmd = run_task.cmd.format(**self.vars)
-                        log.info(run_task.cmd)
                     if self.kill:
                         break
                     self.current = run_task
